#if defined(WITH_C)
#include "c.h"
#endif

int b_fun(void){
#if defined(WITH_C)
return c_fun();
#else
return 0;
#endif
}
